# Etsy-API-V3
 
# Etsy Api V3 SDK nedir?

Etsy API V3 Sdk'sı tamamiyle etsy uygulamalarını rahatlıkla geliştirme amacıyla ortaya çıkmıştır. Basit Bir Kullanımı Olup, Onlarca Satır Koddan kurtulabilirsiniz.

# Etsy API V3 SDK'Sı İle Neler Yapılabilir?

Etsy API V3 SDK'sı ile; Sipariş Bilgierinizi Çekebilir, Rakip Listeler Hakkında Veya Kendi Listeleriniz Hakkında Bilgi Toplayabilir, Siparişlerinizi Gönderildi Yapabilirsiniz.. Ve Çok Daha Fazla özellik sizin hayal gücünüze Kalmış Durumda.

# Etsy API V3 Kullanımı Nasıl?

Etsy api v3'ü kullanabilmek için examples dosyası her gün güncellenecektir. Oradan işinize yarayan kısmı öğrenebilirsiniz.


# Etsy API V3'ü Kullanmak İçin Gerekenler Nedir?

Etsy API V3'ü Kullanmak İçin öncelikle https://developers.etsy.com/ kısmından bir api v3 uygulaması oluşturmanız gerekmektedir.

Daha sonrasında uygulamayı oluşturup, bir api token oluşturmanız gerekiyor onun yardımcı kodları da api v3 içerisinde var.

Daha sonrasında basit bir kullanımla etsy api v3 sdksını kullanabilirsiniz.
